@@ -1,3 +1,5 @@
+sentryRealtime = true;
+
 function getElementsByClassName(oElm, strTagName, strClassName){
 	// Written by Jonathan Snook, http://www.snook.ca/jon; Add-ons by Robert Nyman, http://www.robertnyman.com
 	var arrElements = (strTagName == "*" && document.all)? document.all :
@@ -50,6 +52,18 @@ function switchPastebinFriendly(link) {
   return false;
 }
 
+function getQueryParams()
+{
+    var vars = {}, hash;
+    var hashes = window.location.href.slice(window.location.href.indexOf('?') + 1).split('&');
+    for(var i = 0; i < hashes.length; i++)
+    {
+        hash = hashes[i].split('=');
+        vars[hash[0]] = hash[1];
+    }
+    return vars;
+}
+
 $.fn.setAllToMaxHeight = function(){
 	return this.height( Math.max.apply(this, $.map( this , function(e){ return $(e).height() }) ) );
 }
@@ -78,20 +92,17 @@ function sentryResolve(gid, remove){
     });
 }
 function sentryRefresh(){
+    data = getQueryParams();
+    data.op = 'poll';
+    if (!sentryRealtime) {
+        return;
+    }
     $.ajax({
       url: SENTRY_JS_API_URL,
       type: 'get',
       dataType: 'json',
-      data: {
-          op: 'poll',
-          logger: '{{ logger }}',
-          server_name: '{{ server_name }}',
-          level: '{{ level }}'
-      },
+      data: data,
       success: function(groups){
-          // $('#message_list').each(function(){
-          //               $(this).removeClass('fresh');
-          //           })
           if (groups.length) {
               $('#no_messages').remove();
           }
@@ -120,7 +131,22 @@ function sentryRefresh(){
                   $(this).remove();
               }
           });
-          setTimeout(sentryRefresh, 3000);          
+          setTimeout(sentryRefresh, 3000);
       }
     });
 }
+$(document).ready(function(){
+    $('#sentry_realtime').click(function(){
+        if ($(this).hasClass('realtime-play')) {
+            $(this).removeClass('realtime-play');
+            $(this).addClass('realtime-pause');
+            $(this).text('Pause Feed');
+            sentryRealtime = true;
+        } else {
+            $(this).addClass('realtime-play');
+            $(this).removeClass('realtime-pause');
+            $(this).text('Go Live');
+            sentryRealtime = false;
+        }
+    });
+});
\ No newline at end of file
